@@ -1,4 +1,3 @@
-import os
 import unittest
 import pickle
 import uuid
@@ -15,6 +14,7 @@ from task_helpers.couriers.redis import (
     RedisClientWorkerTaskCourier,
 )
 from task_helpers import exceptions
+from ..mixins import RedisSetupMixin
 
 
 class FullQueueNameMixinTestCase(unittest.TestCase):
@@ -50,29 +50,6 @@ class FullQueueNameMixinTestCase(unittest.TestCase):
         self.assertEqual(name, "test_queue_name")
 
 
-class RedisSetupMixin:
-    """
-    mixin for redis connection initializing.
-    """
-
-    def setUp(self):
-        redis_host = os.environ.get("REDIS_HOST")
-        redis_port = os.environ.get("REDIS_PORT")
-        redis_db = os.environ.get("REDIS_DB")
-        redis_password = os.environ.get("REDIS_PASSWORD", None)
-
-        assert redis_host is not None, "redis_host is None"
-        assert redis_port is not None, "redis_port is None"
-        assert redis_db is not None, "redis_db is None"
-
-        self.redis_connection = redis.Redis(
-            host=redis_host,
-            port=redis_port,
-            db=redis_db,
-            password=redis_password)
-        self.redis_connection.flushdb()
-
-
 def test_func(text):
     return f"{text}{text}"
 
@@ -90,6 +67,11 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
     class TimeoutTestException(TimeoutError):
         pass
 
+    def test___init__(self):
+        courier = RedisClientTaskCourier(self.task_courier.redis_connection)
+        self.assertEqual(courier.redis_connection,
+                         self.task_courier.redis_connection)
+
     def test__generate_task_id(self):
         task_id = self.task_courier._generate_task_id()
         self.assertEqual(type(task_id), uuid.UUID)
@@ -176,21 +158,25 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
                 task_id=task_id)
 
     def test_get_task_result_if_result_is_PerformTaskError(self):
-        before_task_result = exceptions.PerformTaskError(
-            exception=Exception(), error_data="ERROR TEXT")
         before_task_id = uuid.uuid1()
+        before_task_result = exceptions.PerformTaskError(
+            task=(before_task_id, "test_data"),
+            exception=Exception(),
+            error_data="ERROR TEXT")
         key_name = self.task_courier._get_full_queue_name(
             queue_name="test_queue_name",
             sufix="results:") + str(before_task_id)
         value = pickle.dumps(before_task_result)
         self.redis_connection.set(name=key_name, value=value)
 
-        with self.assertRaises(exceptions.PerformTaskError) as context:
-            self.task_courier.get_task_result(
-                queue_name="test_queue_name",
-                task_id=before_task_id)
-        self.assertEqual(type(context.exception.exception), Exception)
-        self.assertEqual(context.exception.error_data, "ERROR TEXT")
+        result = self.task_courier.get_task_result(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+        self.assertEqual(type(result), exceptions.PerformTaskError)
+        self.assertEqual(type(result.exception), Exception)
+        self.assertEqual(result.error_data, "ERROR TEXT")
+        self.assertEqual(result.task[0], before_task_id)
+        self.assertEqual(result.task[1], "test_data")
 
     def test_wait_for_task_result_if_delete_data_True(self):
         before_task_result = "test_result_123"
@@ -281,7 +267,7 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
         done_status = self.task_courier.check_for_done(
             queue_name="test_queue_name",
             task_id=before_task_id)
-        self.assertEqual(done_status, False)
+        self.assertFalse(done_status)
 
     def test_check_for_done_if_done_successfully(self):
         before_task_result = "test_result_123"
@@ -297,14 +283,14 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
         after_task_result = self.task_courier.get_task_result(
             queue_name="test_queue_name",
             task_id=before_task_id)
-
-        self.assertEqual(done_status, True)
+        self.assertTrue(done_status)
         self.assertEqual(after_task_result, before_task_result)
 
     def test_check_for_done_if_done_with_error(self):
-        before_task_result = exceptions.PerformTaskError(
-            exception=Exception())
         before_task_id = uuid.uuid1()
+        before_task_result = exceptions.PerformTaskError(
+            task=(before_task_id, "test_data"),
+            exception=Exception())
         key_name = self.task_courier._get_full_queue_name(
             queue_name="test_queue_name",
             sufix="results:") + str(before_task_id)
@@ -313,11 +299,35 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
         done_status = self.task_courier.check_for_done(
             queue_name="test_queue_name",
             task_id=before_task_id)
-        with self.assertRaises(exceptions.PerformTaskError):
-            self.task_courier.get_task_result(
-                queue_name="test_queue_name",
-                task_id=before_task_id)
-        self.assertEqual(done_status, True)
+        result = self.task_courier.get_task_result(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+        self.assertTrue(done_status)
+        self.assertEqual(type(result), exceptions.PerformTaskError)
+        self.assertEqual(result.task[0], before_task_id)
+        self.assertEqual(result.task[1], "test_data")
+
+    class ClassWithRequiredInitArgs:
+        def __init__(self, arg1, *, kwarg1):
+            self.arg1 = arg1
+            self.kwarg1 = kwarg1
+
+    def test_result_as_class_with_required_init_args(self):
+        before_task_id = uuid.uuid1()
+        before_task_result = self.ClassWithRequiredInitArgs("1", kwarg1="text")
+        key_name = self.task_courier._get_full_queue_name(
+            queue_name="test_queue_name",
+            sufix="results:") + str(before_task_id)
+        value = pickle.dumps(before_task_result)
+        self.redis_connection.set(name=key_name, value=value)
+
+        result = self.task_courier.get_task_result(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+
+        self.assertEqual(type(result), self.ClassWithRequiredInitArgs)
+        self.assertEqual(result.arg1, "1")
+        self.assertEqual(result.kwarg1, "text")
 
 
 class RedisWorkerTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
@@ -333,6 +343,11 @@ class RedisWorkerTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
     class TimeoutTestException(TimeoutError):
         pass
 
+    def test___init__(self):
+        courier = RedisClientTaskCourier(self.task_courier.redis_connection)
+        self.assertEqual(courier.redis_connection,
+                         self.task_courier.redis_connection)
+
     def test_return_task_result(self):
         queue_name = "test_queue"
         task_id = uuid.uuid1()
@@ -519,6 +534,11 @@ class RedisClientWorkerTaskCourierTestCase(
         self.task_courier = RedisClientWorkerTaskCourier(
             redis_connection=self.redis_connection)
 
+    def test___init__(self):
+        courier = RedisClientTaskCourier(self.task_courier.redis_connection)
+        self.assertEqual(courier.redis_connection,
+                         self.task_courier.redis_connection)
+
 
 if __name__ == "__main__":
     unittest.main()
